pub fn is_available(kind: SensorKind) -> boolExpand description
Whether the device has the given sensor (and the platform an API for it). false also covers
simulators/emulators without sensor passthrough and desktops without motion hardware.
pub fn is_available(kind: SensorKind) -> boolWhether the device has the given sensor (and the platform an API for it). false also covers
simulators/emulators without sensor passthrough and desktops without motion hardware.